@@ -1,13 +1,20 @@
 module Data.Function.Compose.LeftToRight (($>), (.>), (<$), (<.)) where
 
+import Prelude hiding ((<$))
+
 (.>) = flip (.)
 infixl 9 .>
+{-# INLINE (.>) #-}
 
 ($>) = flip ($)
 infixl 0 $>
+{-# INLINE ($>) #-}
+
 
 (<$) = ($)
-infixl 1 <$
+infixr 1 <$
+{-# INLINE (<$) #-}
 
 (<.) = (.)
-infixl 9 <.
+infixr 9 <.
+{-# INLINE (<.) #-}
